@@ -6,6 +6,11 @@ CMAKE_ARGS="$CMAKE_ARGS -DCURSES_INCLUDE_PATH=${PREFIX}/include -DBUILD_CursesDi
 CMAKE_ARGS="$CMAKE_ARGS -DCMAKE_PREFIX_PATH=${PREFIX}"
 
 if [[ "$CONDA_BUILD_CROSS_COMPILATION" == "1" ]]; then
+   if [[ "$target_platform" == osx-* ]] && [[ "$MACOSX_DEPLOYMENT_TARGET" == 11.* || "$MACOSX_DEPLOYMENT_TARGET" == "10.15" ]]; then
+       CMAKE_ARGS="$CMAKE_ARGS -DCMake_HAVE_CXX_FILESYSTEM=1"
+   else
+       CMAKE_ARGS="$CMAKE_ARGS -DCMake_HAVE_CXX_FILESYSTEM=0"
+   fi
    cmake ${CMAKE_ARGS} \
        -DCMAKE_VERBOSE_MAKEFILE=1 \
        -DCMAKE_INSTALL_PREFIX=$PREFIX \
@@ -13,7 +18,7 @@ if [[ "$CONDA_BUILD_CROSS_COMPILATION" == "1" ]]; then
        -DBUILD_QtDialog=OFF \
        -DCMAKE_USE_SYSTEM_LIBRARY_LIBARCHIVE=OFF \
        -DCMAKE_USE_SYSTEM_LIBRARY_JSONCPP=OFF \
-       .
+       . || (cat TryRunResults.cmake; false)
 else
   ./bootstrap \
        --verbose \
